/**
* Eric Meyer's Reset CSS v2.0 (http://meyerweb.com/eric/tools/css/reset/)
* http://cssreset.com
*/
html, body, div, span, applet, object, iframe, h1, h2, h3, h4, h5, h6, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, img, ins, kbd, q, s, samp, small, strike, strong, sub, sup, tt, var, b, u, i, center, dl, dt, dd, ol, ul, li, fieldset, form, label, legend, table, caption, tbody, tfoot, thead, tr, th, td, article, aside, canvas, details, embed, figure, figcaption, footer, header, hgroup, menu, nav, output, ruby, section, summary, time, mark, audio, video {
    margin: 0;
    padding: 0;
    border: 0;
    font-size: 100%;
    font: inherit;
    vertical-align: baseline
    }

/* HTML5 display-role reset for older browsers */
article, aside, details, figcaption, figure, footer, header, hgroup, menu, nav, section {
    display: block
    }

body {
    line-height: 1
    }

ol, ul {
    list-style: none
    }

blockquote, q {
    quotes: none
    }

blockquote:before, blockquote:after, q:before, q:after {
    content: "";
    content: none
    }

table {
    border-collapse: collapse;
    border-spacing: 0
    }

/*! jQuery UI - v1.10.3 - 2013-05-11
* http://jqueryui.com
* Includes: jquery.ui.core.css, jquery.ui.resizable.css, jquery.ui.button.css, jquery.ui.dialog.css
* To view and modify this theme, visit http://jqueryui.com/themeroller/?ffDefault=Verdana%2CArial%2Csans-serif&fwDefault=normal&fsDefault=1.1em&cornerRadius=4px&bgColorHeader=%23cccccc&bgTextureHeader=highlight_soft&bgImgOpacityHeader=75&borderColorHeader=%23aaaaaa&fcHeader=%23222222&iconColorHeader=%23222222&bgColorContent=%23ffffff&bgTextureContent=flat&bgImgOpacityContent=75&borderColorContent=%23aaaaaa&fcContent=%23222222&iconColorContent=%23222222&bgColorDefault=%23e6e6e6&bgTextureDefault=glass&bgImgOpacityDefault=75&borderColorDefault=%23d3d3d3&fcDefault=%23555555&iconColorDefault=%23888888&bgColorHover=%23dadada&bgTextureHover=glass&bgImgOpacityHover=75&borderColorHover=%23999999&fcHover=%23212121&iconColorHover=%23454545&bgColorActive=%23ffffff&bgTextureActive=glass&bgImgOpacityActive=65&borderColorActive=%23aaaaaa&fcActive=%23212121&iconColorActive=%23454545&bgColorHighlight=%23fbf9ee&bgTextureHighlight=glass&bgImgOpacityHighlight=55&borderColorHighlight=%23fcefa1&fcHighlight=%23363636&iconColorHighlight=%232e83ff&bgColorError=%23fef1ec&bgTextureError=glass&bgImgOpacityError=95&borderColorError=%23cd0a0a&fcError=%23cd0a0a&iconColorError=%23cd0a0a&bgColorOverlay=%23aaaaaa&bgTextureOverlay=diagonals_thick&bgImgOpacityOverlay=50&opacityOverlay=60&bgColorShadow=%23aaaaaa&bgTextureShadow=flat&bgImgOpacityShadow=0&opacityShadow=30&thicknessShadow=8px&offsetTopShadow=-8px&offsetLeftShadow=-8px&cornerRadiusShadow=8px
* Copyright 2013 jQuery Foundation and other contributors Licensed MIT */
/* Layout helpers
----------------------------------*/
.ui-helper-hidden {
    display: none
    }

.ui-helper-hidden-accessible {
    border: 0;
    clip: rect(0 0 0 0);
    height: 1px;
    margin: -1px;
    overflow: hidden;
    padding: 0;
    position: absolute;
    width: 1px
    }

.ui-helper-reset {
    margin: 0;
    padding: 0;
    border: 0;
    outline: 0;
    line-height: 1.3;
    text-decoration: none;
    font-size: 100%;
    list-style: none
    }

.ui-helper-clearfix:before, .ui-helper-clearfix:after {
    content: "";
    display: table;
    border-collapse: collapse
    }

.ui-helper-clearfix:after {
    clear: both
    }

.ui-helper-clearfix {
    min-height: 0;
    /* support: IE7 */
    }

.ui-helper-zfix {
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;
    position: absolute;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    filter: alpha(opacity=0);
    opacity: 0;
    filter: Alpha(Opacity=0)
    }

.ui-front {
    z-index: 100
    }

/* Interaction Cues
----------------------------------*/
.ui-state-disabled {
    cursor: default !important
    }

/* Icons
----------------------------------*/
/* states and images */
.ui-icon {
    display: block;
    text-indent: -99999px;
    overflow: hidden;
    background-repeat: no-repeat
    }

/* Misc visuals
----------------------------------*/
/* Overlays */
.ui-widget-overlay {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%
    }

.ui-resizable {
    position: relative
    }

.ui-resizable-handle {
    position: absolute;
    font-size: 0.1px;
    display: block
    }

.ui-resizable-disabled .ui-resizable-handle, .ui-resizable-autohide .ui-resizable-handle {
    display: none
    }

.ui-resizable-n {
    cursor: n-resize;
    height: 7px;
    width: 100%;
    top: -5px;
    left: 0
    }

.ui-resizable-s {
    cursor: s-resize;
    height: 7px;
    width: 100%;
    bottom: -5px;
    left: 0
    }

.ui-resizable-e {
    cursor: e-resize;
    width: 7px;
    right: -5px;
    top: 0;
    height: 100%
    }

.ui-resizable-w {
    cursor: w-resize;
    width: 7px;
    left: -5px;
    top: 0;
    height: 100%
    }

.ui-resizable-se {
    cursor: se-resize;
    width: 12px;
    height: 12px;
    right: 1px;
    bottom: 1px
    }

.ui-resizable-sw {
    cursor: sw-resize;
    width: 9px;
    height: 9px;
    left: -5px;
    bottom: -5px
    }

.ui-resizable-nw {
    cursor: nw-resize;
    width: 9px;
    height: 9px;
    left: -5px;
    top: -5px
    }

.ui-resizable-ne {
    cursor: ne-resize;
    width: 9px;
    height: 9px;
    right: -5px;
    top: -5px
    }

.ui-button {
    display: inline-block;
    position: relative;
    padding: 0;
    line-height: normal;
    margin-right: 0.1em;
    cursor: pointer;
    vertical-align: middle;
    text-align: center;
    overflow: visible;
    /* removes extra width in IE */
    }

.ui-button, .ui-button:link, .ui-button:visited, .ui-button:hover, .ui-button:active {
    text-decoration: none
    }

/* to make room for the icon, a width needs to be set here */
.ui-button-icon-only {
    width: 2.2em
    }

/* button elements seem to need a little more width */
button.ui-button-icon-only {
    width: 2.4em
    }

.ui-button-icons-only {
    width: 3.4em
    }

button.ui-button-icons-only {
    width: 3.7em
    }

/* button text element */
.ui-button .ui-button-text {
    display: block;
    line-height: normal
    }

.ui-button-text-only .ui-button-text {
    padding: 0.4em 1em
    }

.ui-button-icon-only .ui-button-text, .ui-button-icons-only .ui-button-text {
    padding: 0.4em;
    text-indent: -9999999px
    }

.ui-button-text-icon-primary .ui-button-text, .ui-button-text-icons .ui-button-text {
    padding: 0.4em 1em 0.4em 2.1em
    }

.ui-button-text-icon-secondary .ui-button-text, .ui-button-text-icons .ui-button-text {
    padding: 0.4em 2.1em 0.4em 1em
    }

.ui-button-text-icons .ui-button-text {
    padding-left: 2.1em;
    padding-right: 2.1em
    }

/* no icon support for input elements, provide padding by default */
input.ui-button {
    padding: 0.4em 1em
    }

/* button icon element(s) */
.ui-button-icon-only .ui-icon, .ui-button-text-icon-primary .ui-icon, .ui-button-text-icon-secondary .ui-icon, .ui-button-text-icons .ui-icon, .ui-button-icons-only .ui-icon {
    position: absolute;
    top: 50%;
    margin-top: -8px
    }

.ui-button-icon-only .ui-icon {
    left: 50%;
    margin-left: -8px
    }

.ui-button-text-icon-primary .ui-button-icon-primary, .ui-button-text-icons .ui-button-icon-primary, .ui-button-icons-only .ui-button-icon-primary {
    left: 0.5em
    }

.ui-button-text-icon-secondary .ui-button-icon-secondary, .ui-button-text-icons .ui-button-icon-secondary, .ui-button-icons-only .ui-button-icon-secondary {
    right: 0.5em
    }

/* button sets */
.ui-buttonset {
    margin-right: 7px
    }

.ui-buttonset .ui-button {
    margin-left: 0;
    margin-right: -0.3em
    }

/* workarounds */
/* reset extra padding in Firefox, see h5bp.com/l */
input.ui-button::-moz-focus-inner, button.ui-button::-moz-focus-inner {
    border: 0;
    padding: 0
    }

.ui-dialog {
    position: absolute;
    top: 0;
    left: 0;
    padding: 0.2em;
    outline: 0
    }

.ui-dialog .ui-dialog-titlebar {
    padding: 0.4em 1em;
    position: relative
    }

.ui-dialog .ui-dialog-title {
    float: left;
    margin: 0.1em 0;
    white-space: nowrap;
    width: 90%;
    overflow: hidden;
    -o-text-overflow: ellipsis;
    -ms-text-overflow: ellipsis;
    text-overflow: ellipsis
    }

.ui-dialog .ui-dialog-titlebar-close {
    position: absolute;
    right: 0.3em;
    top: 50%;
    width: 21px;
    margin: -10px 0 0 0;
    padding: 1px;
    height: 20px
    }

.ui-dialog .ui-dialog-content {
    position: relative;
    border: 0;
    padding: 0.5em 1em;
    background: none;
    overflow: auto
    }

.ui-dialog .ui-dialog-buttonpane {
    text-align: left;
    border-width: 1px 0 0 0;
    background-image: none;
    margin-top: 0.5em;
    padding: 0.3em 1em 0.5em 0.4em
    }

.ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
    float: right
    }

.ui-dialog .ui-dialog-buttonpane button {
    margin: 0.5em 0.4em 0.5em 0;
    cursor: pointer
    }

.ui-dialog .ui-resizable-se {
    width: 12px;
    height: 12px;
    right: -5px;
    bottom: -5px;
    background-position: 16px 16px
    }

.ui-draggable .ui-dialog-titlebar {
    cursor: move
    }

/* Component containers
----------------------------------*/
.ui-widget {
    font-family: Verdana, Arial, sans-serif;
    font-size: 1.1em
    }

.ui-widget .ui-widget {
    font-size: 1em
    }

.ui-widget input, .ui-widget select, .ui-widget textarea, .ui-widget button {
    font-family: Verdana, Arial, sans-serif;
    font-size: 1em
    }

.ui-widget-content {
    border: 1px solid #aaa;
    background: #fff url(../images/jquery-ui/ui-bg_flat_75_ffffff_40x100.png) 50% 50% repeat-x;
    color: #222
    }

.ui-widget-content a {
    color: #222
    }

.ui-widget-header {
    border: 1px solid #aaa;
    background: #ccc url(../images/jquery-ui/ui-bg_highlight-soft_75_cccccc_1x100.png) 50% 50% repeat-x;
    color: #222;
    font-weight: bold
    }

.ui-widget-header a {
    color: #222
    }

/* Interaction states
----------------------------------*/
.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
    border: 1px solid #d3d3d3;
    background: #e6e6e6 url(../images/jquery-ui/ui-bg_glass_75_e6e6e6_1x400.png) 50% 50% repeat-x;
    font-weight: normal;
    color: #555
    }

.ui-state-default a, .ui-state-default a:link, .ui-state-default a:visited {
    color: #555;
    text-decoration: none
    }

.ui-state-hover, .ui-widget-content .ui-state-hover, .ui-widget-header .ui-state-hover, .ui-state-focus, .ui-widget-content .ui-state-focus, .ui-widget-header .ui-state-focus {
    border: 1px solid #999;
    background: #dadada url(../images/jquery-ui/ui-bg_glass_75_dadada_1x400.png) 50% 50% repeat-x;
    font-weight: normal;
    color: #212121
    }

.ui-state-hover a, .ui-state-hover a:hover, .ui-state-hover a:link, .ui-state-hover a:visited {
    color: #212121;
    text-decoration: none
    }

.ui-state-active, .ui-widget-content .ui-state-active, .ui-widget-header .ui-state-active {
    border: 1px solid #aaa;
    background: #fff url(../images/jquery-ui/ui-bg_glass_65_ffffff_1x400.png) 50% 50% repeat-x;
    font-weight: normal;
    color: #212121
    }

.ui-state-active a, .ui-state-active a:link, .ui-state-active a:visited {
    color: #212121;
    text-decoration: none
    }

/* Interaction Cues
----------------------------------*/
.ui-state-highlight, .ui-widget-content .ui-state-highlight, .ui-widget-header .ui-state-highlight {
    border: 1px solid #fcefa1;
    background: #fbf9ee url(../images/jquery-ui/ui-bg_glass_55_fbf9ee_1x400.png) 50% 50% repeat-x;
    color: #363636
    }

.ui-state-highlight a, .ui-widget-content .ui-state-highlight a, .ui-widget-header .ui-state-highlight a {
    color: #363636
    }

.ui-state-error, .ui-widget-content .ui-state-error, .ui-widget-header .ui-state-error {
    border: 1px solid #cd0a0a;
    background: #fef1ec url(../images/jquery-ui/ui-bg_glass_95_fef1ec_1x400.png) 50% 50% repeat-x;
    color: #cd0a0a
    }

.ui-state-error a, .ui-widget-content .ui-state-error a, .ui-widget-header .ui-state-error a {
    color: #cd0a0a
    }

.ui-state-error-text, .ui-widget-content .ui-state-error-text, .ui-widget-header .ui-state-error-text {
    color: #cd0a0a
    }

.ui-priority-primary, .ui-widget-content .ui-priority-primary, .ui-widget-header .ui-priority-primary {
    font-weight: bold
    }

.ui-priority-secondary, .ui-widget-content .ui-priority-secondary, .ui-widget-header .ui-priority-secondary {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    filter: alpha(opacity=70);
    opacity: 0.7;
    filter: Alpha(Opacity=70);
    font-weight: normal
    }

.ui-state-disabled, .ui-widget-content .ui-state-disabled, .ui-widget-header .ui-state-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=35)";
    filter: alpha(opacity=35);
    opacity: 0.35;
    filter: Alpha(Opacity=35);
    background-image: none
    }

.ui-state-disabled .ui-icon {
    filter: Alpha(Opacity=35);
    /* For IE8 - See #6059 */
    }

/* Icons
----------------------------------*/
/* states and images */
.ui-icon {
    width: 16px;
    height: 16px
    }

.ui-icon, .ui-widget-content .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_222222_256x240.png)
    }

.ui-widget-header .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_222222_256x240.png)
    }

.ui-state-default .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_888888_256x240.png)
    }

.ui-state-hover .ui-icon, .ui-state-focus .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_454545_256x240.png)
    }

.ui-state-active .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_454545_256x240.png)
    }

.ui-state-highlight .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_2e83ff_256x240.png)
    }

.ui-state-error .ui-icon, .ui-state-error-text .ui-icon {
    background-image: url(../images/jquery-ui/ui-icons_cd0a0a_256x240.png)
    }

/* positioning */
.ui-icon-blank {
    background-position: 16px 16px
    }

.ui-icon-carat-1-n {
    background-position: 0 0
    }

.ui-icon-carat-1-ne {
    background-position: -16px 0
    }

.ui-icon-carat-1-e {
    background-position: -32px 0
    }

.ui-icon-carat-1-se {
    background-position: -48px 0
    }

.ui-icon-carat-1-s {
    background-position: -64px 0
    }

.ui-icon-carat-1-sw {
    background-position: -80px 0
    }

.ui-icon-carat-1-w {
    background-position: -96px 0
    }

.ui-icon-carat-1-nw {
    background-position: -112px 0
    }

.ui-icon-carat-2-n-s {
    background-position: -128px 0
    }

.ui-icon-carat-2-e-w {
    background-position: -144px 0
    }

.ui-icon-triangle-1-n {
    background-position: 0 -16px
    }

.ui-icon-triangle-1-ne {
    background-position: -16px -16px
    }

.ui-icon-triangle-1-e {
    background-position: -32px -16px
    }

.ui-icon-triangle-1-se {
    background-position: -48px -16px
    }

.ui-icon-triangle-1-s {
    background-position: -64px -16px
    }

.ui-icon-triangle-1-sw {
    background-position: -80px -16px
    }

.ui-icon-triangle-1-w {
    background-position: -96px -16px
    }

.ui-icon-triangle-1-nw {
    background-position: -112px -16px
    }

.ui-icon-triangle-2-n-s {
    background-position: -128px -16px
    }

.ui-icon-triangle-2-e-w {
    background-position: -144px -16px
    }

.ui-icon-arrow-1-n {
    background-position: 0 -32px
    }

.ui-icon-arrow-1-ne {
    background-position: -16px -32px
    }

.ui-icon-arrow-1-e {
    background-position: -32px -32px
    }

.ui-icon-arrow-1-se {
    background-position: -48px -32px
    }

.ui-icon-arrow-1-s {
    background-position: -64px -32px
    }

.ui-icon-arrow-1-sw {
    background-position: -80px -32px
    }

.ui-icon-arrow-1-w {
    background-position: -96px -32px
    }

.ui-icon-arrow-1-nw {
    background-position: -112px -32px
    }

.ui-icon-arrow-2-n-s {
    background-position: -128px -32px
    }

.ui-icon-arrow-2-ne-sw {
    background-position: -144px -32px
    }

.ui-icon-arrow-2-e-w {
    background-position: -160px -32px
    }

.ui-icon-arrow-2-se-nw {
    background-position: -176px -32px
    }

.ui-icon-arrowstop-1-n {
    background-position: -192px -32px
    }

.ui-icon-arrowstop-1-e {
    background-position: -208px -32px
    }

.ui-icon-arrowstop-1-s {
    background-position: -224px -32px
    }

.ui-icon-arrowstop-1-w {
    background-position: -240px -32px
    }

.ui-icon-arrowthick-1-n {
    background-position: 0 -48px
    }

.ui-icon-arrowthick-1-ne {
    background-position: -16px -48px
    }

.ui-icon-arrowthick-1-e {
    background-position: -32px -48px
    }

.ui-icon-arrowthick-1-se {
    background-position: -48px -48px
    }

.ui-icon-arrowthick-1-s {
    background-position: -64px -48px
    }

.ui-icon-arrowthick-1-sw {
    background-position: -80px -48px
    }

.ui-icon-arrowthick-1-w {
    background-position: -96px -48px
    }

.ui-icon-arrowthick-1-nw {
    background-position: -112px -48px
    }

.ui-icon-arrowthick-2-n-s {
    background-position: -128px -48px
    }

.ui-icon-arrowthick-2-ne-sw {
    background-position: -144px -48px
    }

.ui-icon-arrowthick-2-e-w {
    background-position: -160px -48px
    }

.ui-icon-arrowthick-2-se-nw {
    background-position: -176px -48px
    }

.ui-icon-arrowthickstop-1-n {
    background-position: -192px -48px
    }

.ui-icon-arrowthickstop-1-e {
    background-position: -208px -48px
    }

.ui-icon-arrowthickstop-1-s {
    background-position: -224px -48px
    }

.ui-icon-arrowthickstop-1-w {
    background-position: -240px -48px
    }

.ui-icon-arrowreturnthick-1-w {
    background-position: 0 -64px
    }

.ui-icon-arrowreturnthick-1-n {
    background-position: -16px -64px
    }

.ui-icon-arrowreturnthick-1-e {
    background-position: -32px -64px
    }

.ui-icon-arrowreturnthick-1-s {
    background-position: -48px -64px
    }

.ui-icon-arrowreturn-1-w {
    background-position: -64px -64px
    }

.ui-icon-arrowreturn-1-n {
    background-position: -80px -64px
    }

.ui-icon-arrowreturn-1-e {
    background-position: -96px -64px
    }

.ui-icon-arrowreturn-1-s {
    background-position: -112px -64px
    }

.ui-icon-arrowrefresh-1-w {
    background-position: -128px -64px
    }

.ui-icon-arrowrefresh-1-n {
    background-position: -144px -64px
    }

.ui-icon-arrowrefresh-1-e {
    background-position: -160px -64px
    }

.ui-icon-arrowrefresh-1-s {
    background-position: -176px -64px
    }

.ui-icon-arrow-4 {
    background-position: 0 -80px
    }

.ui-icon-arrow-4-diag {
    background-position: -16px -80px
    }

.ui-icon-extlink {
    background-position: -32px -80px
    }

.ui-icon-newwin {
    background-position: -48px -80px
    }

.ui-icon-refresh {
    background-position: -64px -80px
    }

.ui-icon-shuffle {
    background-position: -80px -80px
    }

.ui-icon-transfer-e-w {
    background-position: -96px -80px
    }

.ui-icon-transferthick-e-w {
    background-position: -112px -80px
    }

.ui-icon-folder-collapsed {
    background-position: 0 -96px
    }

.ui-icon-folder-open {
    background-position: -16px -96px
    }

.ui-icon-document {
    background-position: -32px -96px
    }

.ui-icon-document-b {
    background-position: -48px -96px
    }

.ui-icon-note {
    background-position: -64px -96px
    }

.ui-icon-mail-closed {
    background-position: -80px -96px
    }

.ui-icon-mail-open {
    background-position: -96px -96px
    }

.ui-icon-suitcase {
    background-position: -112px -96px
    }

.ui-icon-comment {
    background-position: -128px -96px
    }

.ui-icon-person {
    background-position: -144px -96px
    }

.ui-icon-print {
    background-position: -160px -96px
    }

.ui-icon-trash {
    background-position: -176px -96px
    }

.ui-icon-locked {
    background-position: -192px -96px
    }

.ui-icon-unlocked {
    background-position: -208px -96px
    }

.ui-icon-bookmark {
    background-position: -224px -96px
    }

.ui-icon-tag {
    background-position: -240px -96px
    }

.ui-icon-home {
    background-position: 0 -112px
    }

.ui-icon-flag {
    background-position: -16px -112px
    }

.ui-icon-calendar {
    background-position: -32px -112px
    }

.ui-icon-cart {
    background-position: -48px -112px
    }

.ui-icon-pencil {
    background-position: -64px -112px
    }

.ui-icon-clock {
    background-position: -80px -112px
    }

.ui-icon-disk {
    background-position: -96px -112px
    }

.ui-icon-calculator {
    background-position: -112px -112px
    }

.ui-icon-zoomin {
    background-position: -128px -112px
    }

.ui-icon-zoomout {
    background-position: -144px -112px
    }

.ui-icon-search {
    background-position: -160px -112px
    }

.ui-icon-wrench {
    background-position: -176px -112px
    }

.ui-icon-gear {
    background-position: -192px -112px
    }

.ui-icon-heart {
    background-position: -208px -112px
    }

.ui-icon-star {
    background-position: -224px -112px
    }

.ui-icon-link {
    background-position: -240px -112px
    }

.ui-icon-cancel {
    background-position: 0 -128px
    }

.ui-icon-plus {
    background-position: -16px -128px
    }

.ui-icon-plusthick {
    background-position: -32px -128px
    }

.ui-icon-minus {
    background-position: -48px -128px
    }

.ui-icon-minusthick {
    background-position: -64px -128px
    }

.ui-icon-close {
    background-position: -80px -128px
    }

.ui-icon-closethick {
    background-position: -96px -128px
    }

.ui-icon-key {
    background-position: -112px -128px
    }

.ui-icon-lightbulb {
    background-position: -128px -128px
    }

.ui-icon-scissors {
    background-position: -144px -128px
    }

.ui-icon-clipboard {
    background-position: -160px -128px
    }

.ui-icon-copy {
    background-position: -176px -128px
    }

.ui-icon-contact {
    background-position: -192px -128px
    }

.ui-icon-image {
    background-position: -208px -128px
    }

.ui-icon-video {
    background-position: -224px -128px
    }

.ui-icon-script {
    background-position: -240px -128px
    }

.ui-icon-alert {
    background-position: 0 -144px
    }

.ui-icon-info {
    background-position: -16px -144px
    }

.ui-icon-notice {
    background-position: -32px -144px
    }

.ui-icon-help {
    background-position: -48px -144px
    }

.ui-icon-check {
    background-position: -64px -144px
    }

.ui-icon-bullet {
    background-position: -80px -144px
    }

.ui-icon-radio-on {
    background-position: -96px -144px
    }

.ui-icon-radio-off {
    background-position: -112px -144px
    }

.ui-icon-pin-w {
    background-position: -128px -144px
    }

.ui-icon-pin-s {
    background-position: -144px -144px
    }

.ui-icon-play {
    background-position: 0 -160px
    }

.ui-icon-pause {
    background-position: -16px -160px
    }

.ui-icon-seek-next {
    background-position: -32px -160px
    }

.ui-icon-seek-prev {
    background-position: -48px -160px
    }

.ui-icon-seek-end {
    background-position: -64px -160px
    }

.ui-icon-seek-start {
    background-position: -80px -160px
    }

/* ui-icon-seek-first is deprecated, use ui-icon-seek-start instead */
.ui-icon-seek-first {
    background-position: -80px -160px
    }

.ui-icon-stop {
    background-position: -96px -160px
    }

.ui-icon-eject {
    background-position: -112px -160px
    }

.ui-icon-volume-off {
    background-position: -128px -160px
    }

.ui-icon-volume-on {
    background-position: -144px -160px
    }

.ui-icon-power {
    background-position: 0 -176px
    }

.ui-icon-signal-diag {
    background-position: -16px -176px
    }

.ui-icon-signal {
    background-position: -32px -176px
    }

.ui-icon-battery-0 {
    background-position: -48px -176px
    }

.ui-icon-battery-1 {
    background-position: -64px -176px
    }

.ui-icon-battery-2 {
    background-position: -80px -176px
    }

.ui-icon-battery-3 {
    background-position: -96px -176px
    }

.ui-icon-circle-plus {
    background-position: 0 -192px
    }

.ui-icon-circle-minus {
    background-position: -16px -192px
    }

.ui-icon-circle-close {
    background-position: -32px -192px
    }

.ui-icon-circle-triangle-e {
    background-position: -48px -192px
    }

.ui-icon-circle-triangle-s {
    background-position: -64px -192px
    }

.ui-icon-circle-triangle-w {
    background-position: -80px -192px
    }

.ui-icon-circle-triangle-n {
    background-position: -96px -192px
    }

.ui-icon-circle-arrow-e {
    background-position: -112px -192px
    }

.ui-icon-circle-arrow-s {
    background-position: -128px -192px
    }

.ui-icon-circle-arrow-w {
    background-position: -144px -192px
    }

.ui-icon-circle-arrow-n {
    background-position: -160px -192px
    }

.ui-icon-circle-zoomin {
    background-position: -176px -192px
    }

.ui-icon-circle-zoomout {
    background-position: -192px -192px
    }

.ui-icon-circle-check {
    background-position: -208px -192px
    }

.ui-icon-circlesmall-plus {
    background-position: 0 -208px
    }

.ui-icon-circlesmall-minus {
    background-position: -16px -208px
    }

.ui-icon-circlesmall-close {
    background-position: -32px -208px
    }

.ui-icon-squaresmall-plus {
    background-position: -48px -208px
    }

.ui-icon-squaresmall-minus {
    background-position: -64px -208px
    }

.ui-icon-squaresmall-close {
    background-position: -80px -208px
    }

.ui-icon-grip-dotted-vertical {
    background-position: 0 -224px
    }

.ui-icon-grip-dotted-horizontal {
    background-position: -16px -224px
    }

.ui-icon-grip-solid-vertical {
    background-position: -32px -224px
    }

.ui-icon-grip-solid-horizontal {
    background-position: -48px -224px
    }

.ui-icon-gripsmall-diagonal-se {
    background-position: -64px -224px
    }

.ui-icon-grip-diagonal-se {
    background-position: -80px -224px
    }

/* Misc visuals
----------------------------------*/
/* Corner radius */
.ui-corner-all, .ui-corner-top, .ui-corner-left, .ui-corner-tl {
    -webkit-border-top-left-radius: 4px;
    -moz-border-radius-topleft: 4px;
    border-top-left-radius: 4px
    }

.ui-corner-all, .ui-corner-top, .ui-corner-right, .ui-corner-tr {
    -webkit-border-top-right-radius: 4px;
    -moz-border-radius-topright: 4px;
    border-top-right-radius: 4px
    }

.ui-corner-all, .ui-corner-bottom, .ui-corner-left, .ui-corner-bl {
    -webkit-border-bottom-left-radius: 4px;
    -moz-border-radius-bottomleft: 4px;
    border-bottom-left-radius: 4px
    }

.ui-corner-all, .ui-corner-bottom, .ui-corner-right, .ui-corner-br {
    -webkit-border-bottom-right-radius: 4px;
    -moz-border-radius-bottomright: 4px;
    border-bottom-right-radius: 4px
    }

/* Overlays */
.ui-widget-overlay {
    background: #aaa url(../images/jquery-ui/ui-bg_diagonals-thick_50_aaaaaa_40x40.png) 50% 50% repeat;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    filter: alpha(opacity=60);
    opacity: 0.6;
    filter: Alpha(Opacity=60)
    }

.ui-widget-shadow {
    margin: -8px 0 0 -8px;
    padding: 8px;
    background: #aaa url(../images/jquery-ui/ui-bg_flat_0_aaaaaa_40x100.png) 50% 50% repeat-x;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    filter: alpha(opacity=30);
    opacity: 0.3;
    filter: Alpha(Opacity=30);
    -webkit-border-radius: 8px;
    -moz-border-radius: 8px;
    border-radius: 8px
    }

a, a:visited, a:hover, a:active {
    text-decoration: none;
    color: #000;
    outline: none
    }

html, body {
    width: 100%;
    height: 100%;
    font-family: sans-serif
    }

body {
    display: -webkit-box;
    display: -moz-box;
    display: box;
    -webkit-box-orient: vertical;
    -moz-box-orient: vertical;
    -ms-box-orient: vertical;
    box-orient: vertical;
    font-size: 12px;
    background: #eee
    }

body > header {
    border-bottom: 1px solid #ccc
    }

body > header > h1 {
    float: left;
    font-size: 20px;
    font-weight: bold;
    padding: 6px 6px 6px 35px;
    background: url(/static/images/icon_32x32.png) no-repeat 1px 1px
    }

body > header > h1 a {
    text-shadow: 0 1px 0 #fff;
    -webkit-transition: all 0.1s ease 0s;
    -moz-transition: all 0.1s ease 0s;
    -o-transition: all 0.1s ease 0s;
    transition: all 0.1s ease 0s
    }

body > header > h1 a:hover {
    color: #666
    }

body > header > nav.app {
    float: right;
    border-left: 1px solid #ccc
    }

body > header > nav.app > ul > li {
    display: block;
    float: left;
    border-left: 1px solid #fff;
    border-right: 1px solid #ccc
    }

body > header > nav.app > ul > li input {
    margin: 6px;
    width: 300px
    }

body > header > nav.app > ul > li a {
    display: block;
    padding: 10px;
    text-decoration: none;
    text-shadow: 0 1px 0 white;
    background: -webkit-linear-gradient(#f4f4f4, #ececec), #ececec;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #f4f4f4), color-stop(1, #ececec)), #ececec;
    background: -moz-linear-gradient(#f4f4f4, #ececec), #ececec;
    background: -o-linear-gradient(#f4f4f4, #ececec), #ececec;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#f4f4f4, EndColorStr=#ececec)";
    background: linear-gradient(#f4f4f4, #ececec), #ececec;
    color: #666;
    text-shadow: 1px 1px 0 #fff
    }

body > header > nav.app > ul > li a:hover, body > header > nav.app > ul > li a:focus {
    background: -webkit-linear-gradient(#eee, #ddd), #ddd;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #eee), color-stop(1, #ddd)), #ddd;
    background: -moz-linear-gradient(#eee, #ddd), #ddd;
    background: -o-linear-gradient(#eee, #ddd), #ddd;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#eee, EndColorStr=#ddd)";
    background: linear-gradient(#eee, #ddd), #ddd;
    color: #333;
    text-decoration: none
    }

body > header > nav.app > ul > li a:active {
    background: -webkit-linear-gradient(#ddd, #eee), #eee;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #ddd), color-stop(1, #eee)), #eee;
    background: -moz-linear-gradient(#ddd, #eee), #eee;
    background: -o-linear-gradient(#ddd, #eee), #eee;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#ddd, EndColorStr=#eee)";
    background: linear-gradient(#ddd, #eee), #eee;
    color: #333;
    text-decoration: none;
    text-shadow: -1px -1px 0 #eee
    }

body > header > nav.app > ul > li.notifications {
    display: none
    }

body > nav.messages {
    height: 9.08333em;
    min-height: 3.08333em;
    position: relative;
    overflow: auto;
    border-top: 1px solid #fff;
    background: #fff
    }

body > nav.messages > table {
    width: 100%
    }

body > nav.messages > table > thead > tr {
    background: #eee;
    color: #333
    }

body > nav.messages > table > thead > tr > th {
    padding: 0.25em;
    font-weight: bold;
    text-shadow: 0 1px 0 #fff;
    text-align: left
    }

body > nav.messages > table > tbody > tr {
    cursor: pointer;
    height: 1em;
    -webkit-transition: all 0.1s ease 0s;
    -moz-transition: all 0.1s ease 0s;
    -o-transition: all 0.1s ease 0s;
    transition: all 0.1s ease 0s;
    color: #333;
    background: #fff
    }

body > nav.messages > table > tbody > tr:hover {
    color: #000
    }

body > nav.messages > table > tbody > tr:nth-child(even) {
    background: #f0f0f0
    }

body > nav.messages > table > tbody > tr.selected {
    background: Highlight;
    color: HighlightText
    }

body > nav.messages > table > tbody > tr.deleted {
    text-decoration: line-through
    }

body > nav.messages > table > tbody > tr td {
    padding: 0.25em
    }

body .resizer {
    padding-bottom: 5px;
    cursor: ns-resize
    }

body .resizer > .ruler {
    border-top: 1px solid #ccc;
    border-bottom: 1px solid #fff
    }

body > article {
    display: -webkit-box;
    display: -moz-box;
    display: box;
    -webkit-box-orient: vertical;
    -moz-box-orient: vertical;
    -ms-box-orient: vertical;
    box-orient: vertical;
    -webkit-box-flex: 1;
    -moz-box-flex: 1;
    -ms-box-flex: 1;
    box-flex: 1
    }

body > article > aside.no-message-mark {
    display: none
    }

body > article.no-message > *, body > article.loading-message > * {
    display: none !important
    }

body > article.no-message > aside.no-message-mark, body > article.loading-message > aside.no-message-mark {
    display: -webkit-box !important;
    display: -moz-box !important;
    display: box !important;
    -webkit-box-pack: center;
    -moz-box-pack: center;
    -ms-box-pack: center;
    box-pack: center;
    -webkit-box-align: center;
    -moz-box-align: center;
    -ms-box-align: center;
    box-align: center;
    -webkit-box-flex: 1;
    -moz-box-flex: 1;
    -ms-box-flex: 1;
    box-flex: 1;
    font-size: 64px;
    font-weight: bold;
    -webkit-user-select: none;
    -moz-user-select: none;
    user-select: none;
    cursor: default;
    color: rgba(255, 255, 255, 0.5);
    text-shadow: rgba(170, 170, 170, 0.5) 1px 1px 1px
    }

body > article.no-message > aside.no-message-mark > div, body > article.loading-message > aside.no-message-mark > div {
    display: none
    }

body > article.no-message div.no-message {
    display: block !important
    }

body > article.loading-message div.loading-message {
    display: block !important
    }

body > article > header {
    overflow: hidden
    }

body > article > header > dl.meta {
    overflow: hidden;
    padding: 0 0.5em 0.5em
    }

body > article > header > dl.meta dt, body > article > header > dl.meta dd {
    padding: 0.25em;
    white-space: nowrap
    }

body > article > header > dl.meta dt {
    float: left;
    clear: left;
    width: 8em;
    margin-right: 0.5em;
    text-align: right;
    font-weight: bold;
    color: #666;
    text-shadow: 0 1px 0 #fff
    }

body > article > header > dl.meta dd.subject {
    font-weight: bold
    }

body > article > header > dl.meta .attachments > ul {
    display: inline
    }

body > article > header > dl.meta .attachments > ul > li {
    display: inline-block;
    margin-right: 0.5em
    }

body > article > header > dl.meta .attachments > ul > li > a {
    color: #00e
    }

body > article > header > nav.views > ul {
    padding: 0 0.5em;
    border-bottom: 1px solid #ccc
    }

body > article > header > nav.views > ul > li.tab {
    display: inline-block
    }

body > article > header > nav.views > ul > li.tab > a {
    display: inline-block;
    padding: 0.5em;
    border: 1px solid #ccc;
    background: #ddd;
    color: #333;
    border-width: 1px 1px 0 1px;
    cursor: pointer;
    text-shadow: 0 1px 0 #eee
    }

body > article > header > nav.views > ul > li.tab.selected > a {
    background: #fff;
    color: #000;
    height: 13px;
    -webkit-box-shadow: 1px 1px 0 #ccc;
    -moz-box-shadow: 1px 1px 0 #ccc;
    box-shadow: 1px 1px 0 #ccc;
    margin-bottom: -2px
    }

body > article > header > nav.views > ul > li.action {
    display: inline-block;
    float: right;
    margin: 0 0.25em
    }

body > article > iframe.body {
    display: -webkit-box;
    display: -moz-box;
    display: box;
    -webkit-box-flex: 1;
    -moz-box-flex: 1;
    -ms-box-flex: 1;
    box-flex: 1;
    background: #fff
    }

.button {
    padding: 0.5em 1em;
    border: 1px solid #ccc;
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
    background: -webkit-linear-gradient(#f4f4f4, #ececec), #ececec;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #f4f4f4), color-stop(1, #ececec)), #ececec;
    background: -moz-linear-gradient(#f4f4f4, #ececec), #ececec;
    background: -o-linear-gradient(#f4f4f4, #ececec), #ececec;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#f4f4f4, EndColorStr=#ececec)";
    background: linear-gradient(#f4f4f4, #ececec), #ececec;
    color: #666 !important;
    text-shadow: 1px 1px 0 #fff;
    text-decoration: none
    }

.button:hover, .button:focus {
    border-color: #999;
    border-bottom-color: #666;
    background: -webkit-linear-gradient(#eee, #ddd), #ddd;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #eee), color-stop(1, #ddd)), #ddd;
    background: -moz-linear-gradient(#eee, #ddd), #ddd;
    background: -o-linear-gradient(#eee, #ddd), #ddd;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#eee, EndColorStr=#ddd)";
    background: linear-gradient(#eee, #ddd), #ddd;
    color: #333 !important;
    text-decoration: none
    }

.button:active {
    border-color: #666;
    border-bottom-color: #999;
    background: -webkit-linear-gradient(#ddd, #eee), #eee;
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0, #ddd), color-stop(1, #eee)), #eee;
    background: -moz-linear-gradient(#ddd, #eee), #eee;
    background: -o-linear-gradient(#ddd, #eee), #eee;
    filter: "progid:DXImageTransform.Microsoft.gradient(startColorStr=#ddd, EndColorStr=#eee)";
    background: linear-gradient(#ddd, #eee), #eee;
    color: #333 !important;
    text-decoration: none;
    text-shadow: -1px -1px 0 #eee
    }

.hidden {
    display: none
    }

.no-close .ui-dialog-titlebar-close {
    display: none
    }

.ui-widget {
    font-size: 1em;
    line-height: 1.1em
    }

p + p {
    margin-top: 1em
    }